<?php

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2014 Jens Schmietendorf (jens@smedja.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/
class tx_newsscheduler_expirednews extends \TYPO3\CMS\Scheduler\Task\AbstractTask {

	/**
	 * Search for news records, which has expired the last day (field endtime),
	 * and sends a mail to the BE User who created the news record (from be_users.email)
	 *
	 * @return    boolean    returns TRUE on success, FALSE on failure
	 */

	public function execute() {

		$template = new tx_newsscheduler_templating();
		if ( ! empty( $this->emailtemplate ) ) {
			$template->initTemplate( $this->emailtemplate );
		} else {
			$template->initTemplate( 'typo3conf/ext/news_scheduler/res/templates/expirednews.html' );
		}

		$startdate = new \DateTime( 'yesterday', new \DateTimeZone( 'Europe/Berlin' ) );
		$enddate   = new \DateTime( 'today', new \DateTimeZone( 'Europe/Berlin' ) );


		$res = $GLOBALS['TYPO3_DB']->exec_SELECTquery(
			$select_fields = 'n.uid, n.title, b.email',
			$from_table = 'tx_news_domain_model_news as n, be_users as b',
			$where_clause = 'n.cruser_id=b.uid AND (n.endtime >=' . $startdate->getTimestamp() . ' AND n.endtime <=' . $enddate->getTimestamp() . ') AND n.deleted=0 AND n.hidden=0',
			$groupBy = '',
			$orderBy = '',
			$limit = ''
		);

		$expiredNews = array();
		while ( $item = $GLOBALS['TYPO3_DB']->sql_fetch_assoc( $res ) ) {
			$expiredNews[] = $item;
		}
		$GLOBALS['TYPO3_DB']->sql_free_result( $res );

		foreach ( $expiredNews as $newsItem ) {
			$this->email = $newsItem['email'];

			if ( empty( $this->email ) !== true ) {
				$this->title                     = $newsItem['title'];
				$markersArray                    = array();
				$markersArray['###NEWSUID###']   = $newsItem['uid'];
				$markersArray['###NEWSTITLE###'] = $this->title;
				$markersArray['###HTMLTITLE###'] = $GLOBALS['LANG']->sL( 'LLL:EXT:news_scheduler/locallang.xml:emailsubject' ) . ' "' . $this->title . '"';

				$mailcontent = $template->renderAllTemplate( $markersArray, '###EMAIl_TEMPLATE###' );

				$mailSubject = $GLOBALS['LANG']->sL( 'LLL:EXT:news_scheduler/locallang.xml:emailsubject' ) . ' "' . $this->title . '"';
				if ( empty ( $this->emailfromname ) ) {
					$this->emailfromname = $this->emailfrom;
				}
				tx_newsscheduler_utils::sendEmail( $this->email, $mailSubject, $mailcontent, 'html', $this->emailfrom, $this->emailfromname, 'utf-8' );
			}
		}

		return true;
	}
}