<?php

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2014 Jens Schmietendorf (jens@smedja.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/
class tx_newsscheduler_expirednews_fields implements \TYPO3\CMS\Scheduler\AdditionalFieldProviderInterface {

	/**
	 * Add inputs for email, name and template path
	 *
	 * @param array $taskInfo Reference to the array containing the info used in the add/edit form
	 * @param object $task When editing, reference to the current task object. Null when adding.
	 * @param \TYPO3\CMS\Scheduler\Controller\SchedulerModuleController $parentObject Reference to the calling object (Scheduler's BE module)
	 *
	 * @return array Array containing all the information pertaining to the additional fields
	 */
	public function getAdditionalFields( array &$taskInfo, $task, \TYPO3\CMS\Scheduler\Controller\SchedulerModuleController $parentObject ) {

		if ( empty( $taskInfo['newsscheduler_expirednews_emailfrom'] ) ) {
			if ( $parentObject->CMD == 'edit' ) {
				$taskInfo['newsscheduler_expirednews_emailfrom'] = $task->emailfrom;
			} else {
				$taskInfo['newsscheduler_expirednews_emailfrom'] = '';
			}
		}

		if ( empty( $taskInfo['newsscheduler_expirednews_emailfromname'] ) ) {
			if ( $parentObject->CMD == 'edit' ) {
				$taskInfo['newsscheduler_expirednews_emailfromname'] = $task->emailfromname;
			} else {
				$taskInfo['newsscheduler_expirednews_emailfromname'] = '';
			}
		}

		if ( empty( $taskInfo['newsscheduler_expirednews_emailtemplate'] ) ) {
			if ( $parentObject->CMD == 'edit' ) {
				$taskInfo['newsscheduler_expirednews_emailtemplate'] = $task->emailtemplate;
			} else {
				$taskInfo['newsscheduler_expirednews_emailtemplate'] = '';
			}
		}

		$additionalFields = array();

		$fieldID                      = 'task_emailfrom';
		$fieldCode                    = '<input type="text" name="tx_scheduler[newsscheduler_expirednews_emailfrom]" id="' . $fieldID . '" value="' . $taskInfo['newsscheduler_expirednews_emailfrom'] . '" size="50" />';
		$additionalFields[ $fieldID ] = array(
			'code'     => $fieldCode,
			'label'    => 'LLL:EXT:news_scheduler/locallang.xml:emailfrom',
			'cshKey'   => 'news_scheduler',
			'cshLabel' => $fieldID
		);

		$fieldID                      = 'task_emailfromname';
		$fieldCode                    = '<input type="text" name="tx_scheduler[newsscheduler_expirednews_emailfromname]" id="' . $fieldID . '" value="' . $taskInfo['newsscheduler_expirednews_emailfromname'] . '" size="50" />';
		$additionalFields[ $fieldID ] = array(
			'code'     => $fieldCode,
			'label'    => 'LLL:EXT:news_scheduler/locallang.xml:emailfromname',
			'cshKey'   => 'news_scheduler',
			'cshLabel' => $fieldID
		);

		$fieldID                      = 'task_emailtemplate';
		$fieldCode                    = '<input type="text" name="tx_scheduler[newsscheduler_expirednews_emailtemplate]" id="' . $fieldID . '" value="' . $taskInfo['newsscheduler_expirednews_emailtemplate'] . '" size="50" />';
		$additionalFields[ $fieldID ] = array(
			'code'     => $fieldCode,
			'label'    => 'LLL:EXT:news_scheduler/locallang.xml:emailtemplate',
			'cshKey'   => 'news_scheduler',
			'cshLabel' => $fieldID
		);

		return $additionalFields;
	}

	/**
	 * Checks that an email address is provided
	 *
	 * @param array $submittedData Reference to the array containing the data submitted by the user
	 * @param \TYPO3\CMS\Scheduler\Controller\SchedulerModuleController $parentObject Reference to the calling object (Scheduler's BE module)
	 *
	 * @return boolean TRUE if validation was ok (or selected class is not relevant), FALSE otherwise
	 */
	public function validateAdditionalFields( array &$submittedData, \TYPO3\CMS\Scheduler\Controller\SchedulerModuleController $parentObject ) {
		$result = true;
		if ( empty( $submittedData['newsscheduler_expirednews_emailfrom'] ) ) {
			$parentObject->addMessage( $GLOBALS['LANG']->sL( 'LLL:EXT:news_scheduler/locallang.xml:emailfromerror' ), t3lib_FlashMessage::ERROR );
			$result = false;
		}

		return $result;
	}

	/**
	 * Save email and template path in task object
	 *
	 * @param array $submittedData Contains data submitted by the user
	 * @param \TYPO3\CMS\Scheduler\Task\AbstractTask $task Reference to the current task object
	 *
	 * @return void
	 */
	public function saveAdditionalFields( array $submittedData, \TYPO3\CMS\Scheduler\Task\AbstractTask $task ) {
		$task->emailfrom     = $submittedData['newsscheduler_expirednews_emailfrom'];
		$task->emailfromname = $submittedData['newsscheduler_expirednews_emailfromname'];
		$task->emailtemplate = $submittedData['newsscheduler_expirednews_emailtemplate'];
	}

}